CREATE TABLE RESOURCE_PROVIDERS (
  PROVIDER_ID VARCHAR(20) NOT NULL,
  RESOURCE_DN VARCHAR(2000),
  RECON_STATUS SMALLINT,
  LAST_RECON_TIME TIMESTAMP,
  MAX_RECON_DURATION BIGINT,
  LOCK_SERVICE SMALLINT,
  REQUEST_ID VARCHAR(20),
  CURRENT_REQUEST_COUNT		BIGINT,
  MAX_REQUEST_COUNT		BIGINT,
  LAST_RESPONSE_TIME		TIMESTAMP,
  RESOURCE_STATUS   SMALLINT,
  RESTART_TIME          TIMESTAMP,
  SERVER VARCHAR(20),
  CONSTRAINT RES_PROV_PK PRIMARY KEY(PROVIDER_ID)
) IN ENROLE_DATA INDEX IN ENROLE_INDEXES;


CREATE TABLE REMOTE_SERVICES_REQUESTS (
  PROVIDER_ID VARCHAR(20),
  REQUEST_ID VARCHAR(20) NOT NULL,
  TYPE SMALLINT,
  OPERATION SMALLINT,
  REQUEST_TIME TIMESTAMP,
  EXPIRATION_TIME TIMESTAMP,
  TARGET VARCHAR(2000),
  SERVICE_DN VARCHAR(2000) NOT NULL,
  DATA CLOB(10M),
  CONNECTION_POINT BLOB(10M),
  CONSTRAINT REMOTE_SVR_REQ_FK FOREIGN KEY (PROVIDER_ID) REFERENCES RESOURCE_PROVIDERS (PROVIDER_ID),
  CONSTRAINT REMOTE_SVR_REQ_PK PRIMARY KEY(REQUEST_ID)
)  IN ENROLE_DATA INDEX IN ENROLE_INDEXES;

CREATE INDEX RS_REQ_PID_X ON REMOTE_SERVICES_REQUESTS(PROVIDER_ID);
CREATE INDEX RS_REQ_RTIME_X ON REMOTE_SERVICES_REQUESTS(REQUEST_TIME);

CREATE TABLE REMOTE_RESOURCES_RECONS (
  PROVIDER_ID VARCHAR(20) NOT NULL,
  RECON_ID BIGINT NOT NULL,
  DAY_OF_MONTH INTEGER,
  MONTH_NUM INTEGER,
  DAY_OF_WEEK INTEGER,
  HOUR_NUM INTEGER,
  MINUTE_NUM INTEGER,
  MAX_DURATION BIGINT,
  LOCK_SERVICE SMALLINT DEFAULT 1,
  CONSTRAINT REM_RES_RECONS_FK FOREIGN KEY(PROVIDER_ID) REFERENCES RESOURCE_PROVIDERS(PROVIDER_ID),
  CONSTRAINT REM_RES_RECONS_PK PRIMARY KEY(PROVIDER_ID, RECON_ID)
) IN ENROLE_DATA INDEX IN ENROLE_INDEXES;

CREATE TABLE REMOTE_RESOURCES_RECON_QUERIES (
  PROVIDER_ID VARCHAR(20) NOT NULL,
  RECON_ID BIGINT NOT NULL,
  QUERY_ID BIGINT NOT NULL,
  RECON_FILTER VARCHAR(4000),
  RECON_BASE VARCHAR(4000),
  MAX_DURATION BIGINT,
  MAX_ENTRIES BIGINT,
  ATTRIBUTES CLOB(10M),
  CONSTRAINT REM_REC_QUERIES_FK FOREIGN KEY(PROVIDER_ID, RECON_ID) REFERENCES REMOTE_RESOURCES_RECONS(PROVIDER_ID, RECON_ID),
  CONSTRAINT REM_REC_QUERIES_PK PRIMARY KEY(PROVIDER_ID, RECON_ID, QUERY_ID)
) IN ENROLE_DATA INDEX IN ENROLE_INDEXES;

CREATE TABLE LCR_INPROGRESS_TABLE (
  TENANT VARCHAR(256) NOT NULL,
  RULE_ID BIGINT NOT NULL,
  RULE_OP VARCHAR(256),
  CHILD_ID BIGINT,
  START_TIME BIGINT,
  ENTITY_ID VARCHAR(256) NOT NULL,
  CONSTRAINT Unique_RuleEntity PRIMARY KEY(RULE_ID,ENTITY_ID)
) IN ENROLE_DATA INDEX IN ENROLE_INDEXES;

CREATE TABLE PO_TOPIC_TABLE (
  TENANT			VARCHAR(256)   NOT NULL,
  TOPIC			  VARCHAR(256)   NOT NULL,
  SERVER			VARCHAR(20),
  CHECKPOINT_TIME BIGINT,
  TOPIC_ID			 BIGINT		   NOT NULL,
  CONSTRAINT Unique_TenantTopic PRIMARY KEY(TENANT,TOPIC),
  CONSTRAINT Unique_TopicID UNIQUE(TOPIC_ID)
) IN ENROLE_DATA INDEX IN ENROLE_INDEXES;

CREATE TABLE PO_NOTIFICATION_TABLE (
  NOTIFICATION_ID   BIGINT  NOT NULL,
  TOPIC_ID			  BIGINT		  NOT NULL,
  SUBJECT			VARCHAR(2000),
  TEXTBODY		   CLOB(100K),
  RECEIVE_TIME		BIGINT		   NOT NULL,
  RECIPIENT_EADDR VARCHAR(320)  NOT NULL,
  RECIPIENT_LOCALE   VARCHAR(256),
  CONSTRAINT TenantTopic_parent
  FOREIGN KEY(TOPIC_ID) REFERENCES PO_TOPIC_TABLE(TOPIC_ID) ON DELETE RESTRICT,
  CONSTRAINT NOTIFICATION_ID_PK PRIMARY KEY(NOTIFICATION_ID)
) IN ENROLE_DATA INDEX IN ENROLE_INDEXES;

CREATE INDEX PO_NotifyIndex ON PO_NOTIFICATION_TABLE(TOPIC_ID);


CREATE TABLE PO_NOTIFICATION_HTMLBODY_TABLE (
  NOTIFICATION_ID			   BIGINT NOT NULL,
  HTMLBODY					  CLOB(100K),
  CONSTRAINT NotificationIDHTML FOREIGN KEY(NOTIFICATION_ID) REFERENCES PO_NOTIFICATION_TABLE(NOTIFICATION_ID) ON DELETE CASCADE,
  CONSTRAINT NOTIFI_ID_HTML_PK PRIMARY KEY(NOTIFICATION_ID)
 ) IN ENROLE_DATA INDEX IN ENROLE_INDEXES;


CREATE TABLE SCHEDULED_MESSAGE (
  SCHEDULED_TIME BIGINT,
  SCHEDULED_MESSAGE_ID BIGINT NOT NULL,
  MESSAGE CLOB(10M),
  SERVER VARCHAR(20),
  CHECKPOINT_TIME BIGINT,
  REFERENCE_ID BIGINT,
  REFERENCE2_ID VARCHAR(50),
  CONSTRAINT SCHED_MSG_PK PRIMARY KEY( SCHEDULED_MESSAGE_ID)
) IN ENROLE_DATA INDEX IN ENROLE_INDEXES;

CREATE INDEX SCH_MSG_TIME_X ON SCHEDULED_MESSAGE (SCHEDULED_TIME, SERVER);

CREATE INDEX SCH_MSG_CHKPNT_X ON SCHEDULED_MESSAGE (CHECKPOINT_TIME);

CREATE INDEX SCH_MSG_REF_X ON SCHEDULED_MESSAGE (REFERENCE_ID);

CREATE INDEX SCHEDULED_MSG_X ON SCHEDULED_MESSAGE (REFERENCE2_ID ASC);

UPDATE SYSSTAT.TABLES SET CARD = 50000 where TABSCHEMA = 'ENROLE' AND TABNAME = 'SCHEDULED_MESSAGE' AND CARD < 50000;

CREATE TABLE NEXTVALUE (
  ID VARCHAR(50) NOT NULL,
  NEXTID INTEGER NOT NULL,
  CONSTRAINT NEXTVALUE_PK PRIMARY KEY(ID)
) IN ENROLE_DATA INDEX IN ENROLE_INDEXES;

CREATE TABLE PROCESS (
  ROOT_PROCESS_ID BIGINT NOT NULL,
  ID BIGINT NOT NULL,
  PARENT_ID BIGINT,
  PARENT_ACTIVITY_ID BIGINT,
  NAME VARCHAR(100),
  TYPE VARCHAR(2) NOT NULL,
  DEFINITION_ID VARCHAR(2000) NOT NULL,
  REQUESTER_TYPE VARCHAR(2),
  REQUESTER VARCHAR(2000),
  REQUESTER_NAME VARCHAR(100),
  DESCRIPTION VARCHAR(300),
  PRIORITY INTEGER,
  SCHEDULED VARCHAR(50),
  STARTED VARCHAR(50),
  COMPLETED VARCHAR(50),
  LASTMODIFIED VARCHAR(50),
  SUBMITTED VARCHAR(50),
  STATE VARCHAR(1),
  NOTIFY INTEGER,
  REQUESTEE VARCHAR(2000),
  REQUESTEE_NAME VARCHAR(100),
  SUBJECT VARCHAR(2000),
  SUBJECT_PROFILE VARCHAR(100),
  SUBJECT_SERVICE VARCHAR(100),
  COMMENTS VARCHAR(200),
  RESULT_SUMMARY VARCHAR(2),
  RESULT_DETAIL CLOB(10M),
  TENANT VARCHAR(2000),
  CONSTRAINT PROCESS_PK PRIMARY KEY(ID)
) IN ENROLE_DATA INDEX IN ENROLE_INDEXES;

CREATE INDEX PROCESS_STATE_X ON PROCESS (STATE ASC);
CREATE INDEX PROCESS_PID_X ON PROCESS (PARENT_ID ASC);
CREATE INDEX PROCESS_VPC1_X ON PROCESS (PARENT_ID ASC, SUBMITTED DESC, ID DESC, STATE ASC) ALLOW REVERSE SCANS;

UPDATE SYSSTAT.TABLES SET CARD = 50000 where TABSCHEMA = 'ENROLE' AND TABNAME = 'PROCESS' AND CARD < 50000;

CREATE TABLE ACTIVITY (
  ID BIGINT NOT NULL,
  PROCESS_ID BIGINT NOT NULL,
  DEFINITION_ID VARCHAR(100) NOT NULL,
  ACTIVITY_INDEX INTEGER,
  LOOP_COUNT INTEGER,
  LOOP_RUNCOUNT INTEGER,
  RETRY_COUNT INTEGER,
  LOCK_COUNT INTEGER,
  SUBPROCESS_ID BIGINT,
  NAME VARCHAR(100),
  DESCRIPTION VARCHAR(300),
  TYPE VARCHAR(1),
  SUBTYPE VARCHAR(2),
  PRIORITY INTEGER,
  STARTED VARCHAR(50),
  COMPLETED VARCHAR(50),
  LASTMODIFIED VARCHAR(50),
  STATE VARCHAR(1),
  RESULT_SUMMARY VARCHAR(5),
  RESULT_DETAIL CLOB(10M),
  CONSTRAINT ACTIVITY_FK FOREIGN KEY(PROCESS_ID)
  REFERENCES PROCESS(ID),
  CONSTRAINT ACTIVITY_PK PRIMARY KEY(ID)
) IN ENROLE_DATA INDEX IN ENROLE_INDEXES;

CREATE UNIQUE INDEX ACTIVITY_KEY ON ACTIVITY (PROCESS_ID, DEFINITION_ID, ACTIVITY_INDEX);
CREATE UNIQUE INDEX ACTIVITY_ID_X ON ACTIVITY (ID ASC) INCLUDE (SUBTYPE);
CREATE INDEX ACTIVITY_PID_X ON ACTIVITY (PROCESS_ID DESC);
CREATE INDEX ACTIVITY_STATE_X ON ACTIVITY (STATE DESC);

UPDATE SYSSTAT.TABLES SET CARD = 50000 where TABSCHEMA = 'ENROLE' AND TABNAME = 'ACTIVITY' AND CARD < 50000;

CREATE TABLE PROCESSDATA (
  PROCESS_ID BIGINT NOT NULL,
  DEF_ID VARCHAR(100) NOT NULL,
  NAME VARCHAR(100),
  CONTEXT VARCHAR(100),
  DESCRIPTION VARCHAR(300),
  TYPE VARCHAR(500),
  COLLECTION_TYPE VARCHAR(500),
  VALUE CLOB(10M),
  SMALL_VALUE VARCHAR(4000),
  VALUE_LAST_MODIFIED BIGINT,
  CONSTRAINT PROCESSDATA_FK FOREIGN KEY(PROCESS_ID)
  REFERENCES PROCESS(ID),
  CONSTRAINT PROCESSDATA_PK PRIMARY KEY(PROCESS_ID,DEF_ID)
) IN ENROLE_DATA INDEX IN ENROLE_INDEXES;

CREATE INDEX PROCESSDATA_PID_X ON PROCESSDATA (PROCESS_ID DESC, DEF_ID DESC);

UPDATE SYSSTAT.TABLES SET CARD = 50000 where TABSCHEMA = 'ENROLE' AND TABNAME = 'PROCESSDATA' AND CARD < 50000;

CREATE TABLE PROCESSLOG (
  ID BIGINT NOT NULL,
  PROCESS_ID BIGINT,
  ACTIVITY_ID BIGINT,
  CREATED VARCHAR(50),
  EVENTTYPE VARCHAR(2) NOT NULL,
  OLD_PARTICIPANT_TYPE VARCHAR(2),
  OLD_PARTICIPANT_ID VARCHAR(2000),
  NEW_PARTICIPANT_TYPE VARCHAR(2),
  NEW_PARTICIPANT_ID VARCHAR(2000),
  REQUESTOR_TYPE VARCHAR(2),
  REQUESTOR VARCHAR(2000),
  OLD_STATE VARCHAR(1),
  NEW_STATE VARCHAR(1),
  DATA_ID VARCHAR(100),
  NEW_DATA CLOB(10M),
  CONSTRAINT PROCESSLOG_FK FOREIGN KEY(PROCESS_ID)
  REFERENCES PROCESS(ID),
  CONSTRAINT PROCESSLOG_PK PRIMARY KEY(ID)
) IN ENROLE_DATA INDEX IN ENROLE_INDEXES;

CREATE TABLE WORKITEM (
  ID BIGINT NOT NULL,
  PROCESS_ID BIGINT NOT NULL,
  ACTIVITY_ID BIGINT NOT NULL,
  CREATED VARCHAR(50),
  INPUT_PARAMETERS CLOB(10M),
  DUE_DATE BIGINT,
  LOCK_OWNER VARCHAR(512),
  DESCRIPTION VARCHAR(4000),
  PROCESS_DEFINITION_ID VARCHAR(512) NOT NULL,
  ACTIVITY_DEFINITION_ID VARCHAR(100) NOT NULL,
  ACTIVITY_TYPE VARCHAR(1),
  ACTIVITY_SUBTYPE VARCHAR(2),
  ACTIVITY_NAME VARCHAR(100),
  REQUESTEE_NAME VARCHAR(100),
  REQUESTER_NAME VARCHAR(100),
  SUBJECT VARCHAR(2000),
  CONSTRAINT WORKITEM2_FK FOREIGN KEY(ACTIVITY_ID)
  REFERENCES ACTIVITY(ID),
  CONSTRAINT WORKITEM_FK FOREIGN KEY(PROCESS_ID)
  REFERENCES PROCESS(ID),
  CONSTRAINT WORKITEM_PK PRIMARY KEY(ID)
) IN ENROLE_DATA INDEX IN ENROLE_INDEXES;

CREATE INDEX WORKITEM_PID_X ON WORKITEM (PROCESS_ID);
CREATE INDEX WORKITEM_AID_X ON WORKITEM (ACTIVITY_ID);
CREATE INDEX WORKITEM_ADEF_X ON WORKITEM (ACTIVITY_DEFINITION_ID);
CREATE INDEX WORKITEM_PDEF_X ON WORKITEM (PROCESS_DEFINITION_ID);

CREATE TABLE WI_PARTICIPANT (
  ID BIGINT NOT NULL,
  WORKITEM_ID BIGINT NOT NULL,
  PARTICIPANT_TYPE VARCHAR(2) NOT NULL,
  PARTICIPANT VARCHAR(512) NOT NULL,
  CONSTRAINT WORKITEM_ID_FK FOREIGN KEY(WORKITEM_ID)
  REFERENCES WORKITEM(ID) ON DELETE CASCADE,
  CONSTRAINT PARTICIPANT_PK PRIMARY KEY(ID)
) IN ENROLE_DATA INDEX IN ENROLE_INDEXES;

CREATE INDEX WIPART_WIID_X ON WI_PARTICIPANT (WORKITEM_ID);
CREATE INDEX WIPART_DN_X ON WI_PARTICIPANT (PARTICIPANT);

CREATE TABLE SYNCH_POINT (
  PROCESS_ID BIGINT NOT NULL,
  DEFINITION_ID VARCHAR(100) NOT NULL,
  ACTIVITY_INDEX INTEGER NOT NULL,
  WAIT_LOCK INTEGER NOT NULL,
  JOIN_ENABLED SMALLINT NOT NULL,
  CONSTRAINT SYNCH_POINT_PK PRIMARY KEY(PROCESS_ID, DEFINITION_ID, ACTIVITY_INDEX)
) IN ENROLE_DATA INDEX IN ENROLE_INDEXES;

CREATE INDEX SYNCH_POINT_PID_X ON SYNCH_POINT (PROCESS_ID DESC);


CREATE TABLE PASSWORD_TRANSACTION (
  TRANSACTION_ID BIGINT NOT NULL,
  ACCOUNT_DN VARCHAR(2000),
  CREATION_DATE VARCHAR(50),
  PROCESS_ID BIGINT NOT NULL,
  ACTIVITY_ID BIGINT NOT NULL,
  PASSWORD VARCHAR(500),
  CONSTRAINT PWD_TRANS_PK PRIMARY KEY(TRANSACTION_ID)
) IN ENROLE_DATA INDEX IN ENROLE_INDEXES;

CREATE TABLE PENDING (
  PROCESS_ID BIGINT NOT NULL,
  PERSON_DN VARCHAR(255),
  SERVICE_DN VARCHAR(2000),
  CONSTRAINT PENDING_FK FOREIGN KEY(PROCESS_ID)
  REFERENCES PROCESS(ID),
  CONSTRAINT PENDING_PK PRIMARY KEY(PROCESS_ID)
) IN ENROLE_DATA INDEX IN ENROLE_INDEXES;

CREATE INDEX PENDING_FOR_PERSON ON PENDING (PERSON_DN);


CREATE TABLE LISTDATA
(
  DATA_ID  BIGINT NOT NULL,
  INDEX_ID  INT NOT NULL,
  VALUE	CLOB(10M),
CONSTRAINT LISTDATA_PK PRIMARY KEY(DATA_ID, INDEX_ID)
) IN ENROLE_DATA INDEX IN ENROLE_INDEXES;

CREATE TABLE REPORT (
  ID INT NOT NULL,
  TITLE VARCHAR(255) NOT NULL,
  TYPE VARCHAR(255) NOT NULL,
  AUTHOR VARCHAR(255),
  REPORT_SIZE INT,
  REPORT_DATA BLOB(10M),
  STYLESHEET_NAME VARCHAR(255),
  EDITABLE CHAR(1),
  REPORTCATEGORY VARCHAR(255) NOT NULL,
  REPORTSUBTYPE VARCHAR(255) NOT NULL,
  CONSTRAINT REPORT_P PRIMARY KEY (ID)
)IN ENROLE_DATA INDEX IN ENROLE_INDEXES;

CREATE TABLE ENTITY_COLUMN (
  ENTITY_NAME VARCHAR(255) NOT NULL,
  COLUMN_NAME VARCHAR(255) NOT NULL,
  ATTRIBUTE_NAME VARCHAR(255) NOT NULL,
  MULTI_VALUED CHAR(1),
  IMPLICITLY_MAPPED CHAR(1),
  AVAILABLE_FOR_REPORTING VARCHAR(255),
  TABLE_NAME VARCHAR(255),

  CONSTRAINT ENTITY_COLUMNP PRIMARY KEY (ENTITY_NAME, ATTRIBUTE_NAME)
)IN ENROLE_DATA INDEX IN ENROLE_INDEXES;


CREATE TABLE COLUMN_REPORT (
  ENTITY_NAME VARCHAR(255) NOT NULL,
  COLUMN_NAME VARCHAR(255) NOT NULL,
  REPORT_ID INT NOT NULL,

  CONSTRAINT COLUMN_REPORT_P PRIMARY KEY (REPORT_ID, ENTITY_NAME, COLUMN_NAME)
)IN ENROLE_DATA INDEX IN ENROLE_INDEXES;

CREATE TABLE AUTHORIZATION_OWNERS (
  USERDN VARCHAR(255) NOT NULL,
  CONTAINERDN VARCHAR(255) NOT NULL,
  PRIMARY KEY(USERDN, CONTAINERDN)
)IN ENROLE_DATA INDEX IN ENROLE_INDEXES;

CREATE TABLE ACI (
  DN VARCHAR(255) NOT NULL,
  NAME VARCHAR(255) NOT NULL,
  SCOPE VARCHAR(255),
  TARGET VARCHAR(255) NOT NULL,
  PARENT VARCHAR(255),
  CATEGORY VARCHAR(255),
  ObjectFilter VARCHAR(1023),
  PRIMARY KEY(DN, NAME, TARGET)
)IN ENROLE_DATA INDEX IN ENROLE_INDEXES;

CREATE TABLE ACI_ROLEDNS (
  DN VARCHAR(255) NOT NULL,
  NAME VARCHAR(255) NOT NULL,
  TARGET VARCHAR(255) NOT NULL,
  ROLEDN VARCHAR(255) NOT NULL
)IN ENROLE_DATA INDEX IN ENROLE_INDEXES;


CREATE TABLE ACI_PRINCIPALS (
  DN VARCHAR(255) NOT NULL,
  NAME VARCHAR(255) NOT NULL,
  TARGET VARCHAR(255) NOT NULL,
  PRINCIPALNAME VARCHAR(255) NOT NULL
)IN ENROLE_DATA INDEX IN ENROLE_INDEXES;

CREATE TABLE ACI_PERMISSION_ATTRIBUTERIGHT (
  DN VARCHAR(255) NOT NULL,
  NAME VARCHAR(255) NOT NULL,
  TARGET VARCHAR(255) NOT NULL,
  ACTION VARCHAR(6) NOT NULL,
  OPERATION VARCHAR(3) NOT NULL,
  ATTRIBUTERIGHT VARCHAR(255) NOT NULL
)IN ENROLE_DATA INDEX IN ENROLE_INDEXES;


CREATE TABLE ACI_PERMISSION_CLASSRIGHT (
  DN VARCHAR(255) NOT NULL,
  NAME VARCHAR(255) NOT NULL,
  TARGET VARCHAR(255) NOT NULL,
  ACTION VARCHAR(6) NOT NULL,
  CLASSRIGHT VARCHAR(255) NOT NULL
)IN ENROLE_DATA INDEX IN ENROLE_INDEXES;


CREATE TABLE ENTITLEMENT (
  DN VARCHAR(255) NOT NULL,
  TYPE VARCHAR(255) NOT NULL,
  SERVICETARGETTYPE VARCHAR(255),
  SERVICETARGETNAME VARCHAR(255),
  PROCESSDN VARCHAR(255)
)IN ENROLE_DATA INDEX IN ENROLE_INDEXES;

CREATE TABLE ENTITLEMENT_PROVISIONINGPARAMS (
  DN VARCHAR(255) NOT NULL,
  ATTRIBUTEVALUE VARCHAR(4000) NOT NULL,
  NAME VARCHAR(255) NOT NULL,
  ENFORCEMENT VARCHAR(255),
  EXPRTYPE VARCHAR(255)
)IN ENROLE_DATA INDEX IN ENROLE_INDEXES;

CREATE TABLE SYNCHRONIZATION_HISTORY (
  SYNC_ID BIGINT  NOT NULL ,
  REQUESTOR VARCHAR (255) NOT NULL,
  REQ_TYPE VARCHAR (255),
  REQ_NAME VARCHAR (255),
  STATUS VARCHAR (255),
  TENANT VARCHAR (255),
  STATUS_DETAIL VARCHAR (255),
  SCHEDULED_TIME BIGINT,
  SUBMITTED_TIME BIGINT,
  STARTED_TIME BIGINT NOT NULL,
  COMPLETED_TIME BIGINT,
  SERVER_NAME VARCHAR (255),
  PRIMARY KEY (SYNC_ID, STARTED_TIME)
)IN ENROLE_DATA INDEX IN ENROLE_INDEXES;


CREATE TABLE SYNCHRONIZATION_LOCK (
  HOST VARCHAR (255) NOT NULL,
  PRIMARY KEY (HOST)
)IN ENROLE_DATA INDEX IN ENROLE_INDEXES;


CREATE TABLE RESOURCES_SYNCHRONIZATIONS (
  SYNC_ID BIGINT  NOT NULL,
  DAY_OF_MONTH INTEGER  NOT NULL,
  MONTH_NUM INTEGER  NOT NULL,
  DAY_OF_WEEK INTEGER  NOT NULL,
  HOUR_NUM INTEGER  NOT NULL,
  MINUTE_NUM INTEGER  NOT NULL,
  MAX_DURATION BIGINT,
  PRIMARY KEY (SYNC_ID)
)IN ENROLE_DATA INDEX IN ENROLE_INDEXES;


CREATE TABLE CHANGELOG (
  CHANGE_NUMBER INTEGER NOT NULL
)IN ENROLE_DATA INDEX IN ENROLE_INDEXES;

CREATE TABLE RECONCILIATION (
  RECONID VARCHAR(255) NOT NULL,
  SERVICEDN VARCHAR(2000) NOT NULL,
  PROCESSEDACCOUNTS INTEGER NOT NULL,
  LOCALACCOUNTS INTEGER NOT NULL,
  TIMUSERACCOUNTS INTEGER NOT NULL,
  POLICYVIOLATIONS INTEGER NOT NULL,
  STARTED TIMESTAMP NOT NULL,
  COMPLETED TIMESTAMP NOT NULL,
  PRIMARY KEY (RECONID)
)IN ENROLE_DATA INDEX IN ENROLE_INDEXES;

CREATE TABLE RECONCILIATION_INFO (
  RECONID VARCHAR(255) NOT NULL,
  ACCOUNTID VARCHAR(255),
  POLICYCOMPLIANCESTATUS VARCHAR(20),
  USERNAME VARCHAR(255),
  OPERATION VARCHAR(20),
  REMARKS VARCHAR(1000),
  FOREIGN KEY (RECONID) REFERENCES RECONCILIATION (RECONID)
)IN ENROLE_DATA INDEX IN ENROLE_INDEXES;


CREATE TABLE AUTH_KEY (
  Y VARCHAR(2000) NOT NULL,
  P VARCHAR(2000) NOT NULL,
  Q VARCHAR(2000) NOT NULL,
  G VARCHAR(2000) NOT NULL,
  X VARCHAR(2000) NOT NULL
)IN ENROLE_DATA INDEX IN ENROLE_INDEXES;

CREATE TABLE WORKFLOW_CALLBACK (
  ID BIGINT NOT NULL,
  PROCESS_ID BIGINT NOT NULL,
  MESSAGE_OBJECT VARCHAR(2000) NOT NULL,
  EVENT_TRIGGER  CHAR(1),
  CONSTRAINT WF_CALLBACK_FK FOREIGN KEY(PROCESS_ID) REFERENCES PROCESS(ID),
  CONSTRAINT WF_CALLBACK_PK PRIMARY KEY(ID)
) IN ENROLE_DATA INDEX IN ENROLE_INDEXES;

CREATE TABLE POLICY_ANALYSIS (
  ANALYSIS_ID	VARCHAR(32) NOT NULL,
  TENANT_NAME VARCHAR(64),
  STATUS INTEGER NOT NULL,
  REASON INTEGER NOT NULL,
  CONTEXT INTEGER NOT NULL,
  CHANGE_TYPE INTEGER NOT NULL,
  LAST_ACCESSED TIMESTAMP NOT NULL,
  WORKERS_STARTED INTEGER DEFAULT 0 NOT NULL,
  WORKERS_COMPLETED INTEGER DEFAULT 0 NOT NULL,
  WORKERS_TOTAL INTEGER DEFAULT 0 NOT NULL,
  ACCOUNTS_EVALUATED INTEGER DEFAULT 0 NOT NULL,
  CONSTRAINT PK_POLICY_ANALYSIS PRIMARY KEY(ANALYSIS_ID)
)
IN ENROLE_DATA INDEX IN ENROLE_INDEXES;

CREATE TABLE ACCT_CHANGE (
  CHANGE_ID VARCHAR(32) NOT NULL,
  ACCT_UID VARCHAR(60) NOT NULL,
  ACCT_IDENTIFIER VARCHAR(255) NOT NULL,
  SERVICE_NAME VARCHAR(200) NOT NULL,
  SERVICE_IDENTIFIER VARCHAR(255) NOT NULL,
  OWNER_NAME VARCHAR(200) NOT NULL,
  OWNER_IDENTIFIER VARCHAR(255) NOT NULL,
  OPERATION_TYPE INTEGER NOT NULL,
  PROVISION_PRIORITY INTEGER,
  SEQUENCE_NR INTEGER,
  REASON INTEGER NOT NULL,
  REVOKE_CHANGE INTEGER NOT NULL,
  STATUS SMALLINT,
  POLICY_ANALYSIS_ID VARCHAR(32) NOT NULL,
  CONSTRAINT FK_POLICY_ANALYSIS FOREIGN KEY(POLICY_ANALYSIS_ID) REFERENCES POLICY_ANALYSIS(ANALYSIS_ID)
	ON DELETE CASCADE,
	CONSTRAINT PK_ACCT_CHANGE PRIMARY KEY(POLICY_ANALYSIS_ID, CHANGE_ID)
)
IN ENROLE_DATA INDEX IN ENROLE_INDEXES;

CREATE TABLE ATTR_CHANGE (
  CHANGE_ID VARCHAR(32) NOT NULL,
  ATTR_NAME VARCHAR(100) NOT NULL,
  ATTR_VALUE VARCHAR(2000),
  OPERATION_TYPE INTEGER NOT NULL,
  PRIVILEGE_ACTION_TYPE INTEGER NOT NULL,
  ATTR_VALUE_PRESENCE INTEGER NOT NULL,
  POLICY_ANALYSIS_ID VARCHAR(32) NOT NULL,
  ACCT_CHANGE_ID VARCHAR(32) NOT NULL,
  CONSTRAINT FK_ATTR_CHANGE FOREIGN KEY(POLICY_ANALYSIS_ID, ACCT_CHANGE_ID)
	REFERENCES ACCT_CHANGE(POLICY_ANALYSIS_ID, CHANGE_ID)
	ON DELETE CASCADE,
	CONSTRAINT PK_ATTR_CHANGE PRIMARY KEY(POLICY_ANALYSIS_ID, ACCT_CHANGE_ID, CHANGE_ID)
)
IN ENROLE_DATA INDEX IN ENROLE_INDEXES;

CREATE TABLE POLICY_ANALYSIS_ERROR (
  ERROR_ID	VARCHAR(32) NOT NULL,
  ENTITY_NAME VARCHAR(100),
  ENTITY_IDENTIFIER VARCHAR(255),
  ENTITY_TYPE  INTEGER,
  SERVICE_NAME VARCHAR(200),
  SERVICE_IDENTIFIER VARCHAR(255),
  PERSON_NAME  VARCHAR(200),
  PERSON_IDENTIFIER VARCHAR(255),
  POLICY_NAME VARCHAR(100),
  POLICY_IDENTIFIER	VARCHAR(255),
  ATTR_NAME VARCHAR(100),
  ERROR_TYPE INTEGER NOT NULL,
  ENTITY_ERROR_TYPE  INTEGER,
  ERROR_MESSAGE CLOB NOT NULL,
  POLICY_ANALYSIS_ID VARCHAR(32) NOT NULL,
  CONSTRAINT FK_ANALYSIS_ERROR FOREIGN KEY(POLICY_ANALYSIS_ID) REFERENCES POLICY_ANALYSIS(ANALYSIS_ID)
	ON DELETE CASCADE,
  CONSTRAINT PK_ANALYSIS_ERROR PRIMARY KEY(ERROR_ID)
)
IN ENROLE_DATA INDEX IN ENROLE_INDEXES;

CREATE TABLE COMPLIANCE_ALERT (
  CA_PROC_ID	 BIGINT,
  CA_ISSUE_DN	VARCHAR(512) NOT NULL,
  ACTIVITY_ID	  BIGINT,
  ACCOUNT_DN	VARCHAR(512) NOT NULL,
  PARTICIPANT_DN  VARCHAR(512),
  STARTED		CHAR(1),
  CONSTRAINT PK_CA PRIMARY KEY(CA_ISSUE_DN)
)
IN ENROLE_DATA INDEX IN ENROLE_INDEXES;

CREATE INDEX CA_PID_X ON COMPLIANCE_ALERT(CA_PROC_ID);
CREATE INDEX CA_ACCDN_X ON COMPLIANCE_ALERT(ACCOUNT_DN);
CREATE INDEX CA_ACTID_X ON COMPLIANCE_ALERT(ACTIVITY_ID);

insert into enrole.entity_column (entity_name, column_name, attribute_name, multi_valued, implicitly_mapped, available_for_reporting, table_name) values ('Account','DN','DN', 'N','N','table_dropped','Account');
insert into enrole.entity_column (entity_name, column_name, attribute_name, multi_valued, implicitly_mapped, available_for_reporting, table_name) values ('Account','eraccountcompliance','eraccountcompliance','N','N','table_dropped','Account');
insert into enrole.entity_column (entity_name, column_name, attribute_name, multi_valued, implicitly_mapped, available_for_reporting, table_name) values ('Account','eraccountstatus','eraccountstatus','N','N','table_dropped','Account');
insert into enrole.entity_column (entity_name, column_name, attribute_name, multi_valued, implicitly_mapped, available_for_reporting, table_name) values ('Account','erlastaccessdate','erlastaccessdate','N','N','table_dropped','Account');
insert into enrole.entity_column (entity_name, column_name, attribute_name, multi_valued, implicitly_mapped, available_for_reporting, table_name) values ('Account','erparent','erparent','N','N','table_dropped','Account');
insert into enrole.entity_column (entity_name, column_name, attribute_name, multi_valued, implicitly_mapped, available_for_reporting, table_name) values ('Account','erservice','erservice','N','N','table_dropped','Account');
insert into enrole.entity_column (entity_name, column_name, attribute_name, multi_valued, implicitly_mapped, available_for_reporting, table_name) values ('Account','eruid','eruid','N','N','table_dropped','Account');
insert into enrole.entity_column (entity_name, column_name, attribute_name, multi_valued, implicitly_mapped, available_for_reporting, table_name) values ('Account','owner','owner','Y','N','table_dropped','Account_owner');
insert into enrole.entity_column (entity_name, column_name, attribute_name, multi_valued, implicitly_mapped, available_for_reporting, table_name) values ('Role','DN','DN','N','N','table_dropped','Role');
insert into enrole.entity_column (entity_name, column_name, attribute_name, multi_valued, implicitly_mapped, available_for_reporting, table_name) values ('Role','errolename','errolename','N','N','table_dropped','Role');
insert into enrole.entity_column (entity_name, column_name, attribute_name, multi_valued, implicitly_mapped, available_for_reporting, table_name) values ('OrganizationalContainer','description','description','Y','N','table_dropped','OrganizationalCont_description');
insert into enrole.entity_column (entity_name, column_name, attribute_name, multi_valued, implicitly_mapped, available_for_reporting, table_name) values ('OrganizationalContainer','DN','DN','N','N','table_dropped','OrganizationalCont0');
insert into enrole.entity_column (entity_name, column_name, attribute_name, multi_valued, implicitly_mapped, available_for_reporting, table_name) values ('OrganizationalContainer','erparent','erparent','N','N','table_dropped','OrganizationalCont0');
insert into enrole.entity_column (entity_name, column_name, attribute_name, multi_valued, implicitly_mapped, available_for_reporting, table_name) values ('OrganizationalContainer','name','name','N','N','table_dropped','OrganizationalCont0');
insert into enrole.entity_column (entity_name, column_name, attribute_name, multi_valued, implicitly_mapped, available_for_reporting, table_name) values ('Person','cn','cn','Y','N','table_dropped','Person_cn');
insert into enrole.entity_column (entity_name, column_name, attribute_name, multi_valued, implicitly_mapped, available_for_reporting, table_name) values ('Person','erparent','erparent','N','N','table_dropped','Person');
insert into enrole.entity_column (entity_name, column_name, attribute_name, multi_valued, implicitly_mapped, available_for_reporting, table_name) values ('Person','DN','DN','N','N','table_dropped','Person');
insert into enrole.entity_column (entity_name, column_name, attribute_name, multi_valued, implicitly_mapped, available_for_reporting, table_name) values ('Person','erpersonstatus','erpersonstatus','N','N','table_dropped','Person');
insert into enrole.entity_column (entity_name, column_name, attribute_name, multi_valued, implicitly_mapped, available_for_reporting, table_name) values ('Person','erroles','erroles','Y','N','table_dropped','Person_erroles');
insert into enrole.entity_column (entity_name, column_name, attribute_name, multi_valued, implicitly_mapped, available_for_reporting, table_name) values ('Person','givenname','givenname','Y','N','table_dropped','Person_givenname');
insert into enrole.entity_column (entity_name, column_name, attribute_name, multi_valued, implicitly_mapped, available_for_reporting, table_name) values ('Person','sn','sn','Y','N','table_dropped','Person_sn');
insert into enrole.entity_column (entity_name, column_name, attribute_name, multi_valued, implicitly_mapped, available_for_reporting, table_name) values ('ProvisioningPolicy','DN','DN','N','N','table_dropped','ProvisioningPolicy');
insert into enrole.entity_column (entity_name, column_name, attribute_name, multi_valued, implicitly_mapped, available_for_reporting, table_name) values ('ProvisioningPolicy','erparent','erparent','N','N','table_dropped','ProvisioningPolicy');
insert into enrole.entity_column (entity_name, column_name, attribute_name, multi_valued, implicitly_mapped, available_for_reporting, table_name) values ('ProvisioningPolicy','erpolicyitemname','erpolicyitemname','N','N','table_dropped','ProvisioningPolicy');
insert into enrole.entity_column (entity_name, column_name, attribute_name, multi_valued, implicitly_mapped, available_for_reporting, table_name) values ('ProvisioningPolicy','erpolicymembership','erpolicymembership','Y','N','table_dropped','ProvPolicy_membership');
insert into enrole.entity_column (entity_name, column_name, attribute_name, multi_valued, implicitly_mapped, available_for_reporting, table_name) values ('ProvisioningPolicy','erpolicytarget','erpolicytarget','Y','N','table_dropped','ProvPolicy_targets');
insert into enrole.entity_column (entity_name, column_name, attribute_name, multi_valued, implicitly_mapped, available_for_reporting, table_name) values ('Service','DN','DN','N','N','table_dropped','Service');
insert into enrole.entity_column (entity_name, column_name, attribute_name, multi_valued, implicitly_mapped, available_for_reporting, table_name) values ('Service','erurl','erurl','N','N','table_dropped','Service');
insert into enrole.entity_column (entity_name, column_name, attribute_name, multi_valued, implicitly_mapped, available_for_reporting, table_name) values ('Service','erparent','erparent','N','N','table_dropped','Service');
insert into enrole.entity_column (entity_name, column_name, attribute_name, multi_valued, implicitly_mapped, available_for_reporting, table_name) values ('Service','erservicename','erservicename','N','N','table_dropped','Service');
insert into enrole.entity_column (entity_name, column_name, attribute_name, multi_valued, implicitly_mapped, available_for_reporting, table_name) values ('Service','owner','owner','Y','N','table_dropped','Service_owner');
insert into enrole.entity_column (entity_name, column_name, attribute_name, multi_valued, implicitly_mapped, available_for_reporting, table_name) values ('Service','servicetype','servicetype','N','N','table_dropped','Service');


create table enrole.AUDIT_EVENT
(
	id BIGINT NOT NULL,
	itim_event_category VARCHAR(50) NOT NULL,
	entity_name VARCHAR(1000),
	entity_dn VARCHAR(1000),
	entity_type VARCHAR(50),
	action VARCHAR(25) NOT NULL,
	workflow_process_id BIGINT,
	initiator_name VARCHAR(1000),
	initiator_dn VARCHAR(1000),
	container_name VARCHAR(1000),
	container_dn VARCHAR(1000),
	result_summary VARCHAR(25),
	timestamp VARCHAR(50) NOT NULL,
	comments VARCHAR(1000),
CONSTRAINT AUDIT_EVENT_PK PRIMARY KEY(id)
)
IN ENROLE_DATA INDEX IN ENROLE_INDEXES;


create table enrole.AUDIT_MGMT_TARGET
(
	event_id BIGINT NOT NULL,
	target_entity_name VARCHAR(1000),
	target_entity_dn VARCHAR(1000),
	target_entity_type VARCHAR(50),
	CONSTRAINT AUDIT_TARGET_FK FOREIGN KEY(event_id)
	REFERENCES enrole.AUDIT_EVENT(id)
)
IN ENROLE_DATA INDEX IN ENROLE_INDEXES;


create table enrole.AUDIT_MGMT_PROVISIONING
(
	event_id BIGINT NOT NULL,
	owner_name VARCHAR(1000),
	owner_dn VARCHAR(1000),
	service_name VARCHAR(1000) NOT NULL,
	service_dn VARCHAR(1000) NOT NULL,
	CONSTRAINT AUDIT_PROV_FK FOREIGN KEY(event_id)
	REFERENCES enrole.AUDIT_EVENT(id)
)
IN ENROLE_DATA INDEX IN ENROLE_INDEXES;

create table enrole.AUDIT_MGMT_DELEGATE
(
	event_id BIGINT NOT NULL,
	delegate_name VARCHAR(1000),
	delegate_dn VARCHAR(1000),
	delegate_start_time VARCHAR(1000),
	delegate_end_time VARCHAR(1000),
	CONSTRAINT AUDIT_DELEGATE_FK FOREIGN KEY(event_id)
	REFERENCES enrole.AUDIT_EVENT(id)
)
IN ENROLE_DATA INDEX IN ENROLE_INDEXES;

CREATE TABLE enrole.I18NMESSAGES (
	PROFILE VARCHAR(256),
	NAME VARCHAR(256) NOT NULL,
	MESSAGEKEY VARCHAR(256) NOT NULL,
	MESSAGE VARCHAR(2000)
)IN ENROLE_DATA INDEX IN ENROLE_INDEXES;

CREATE TABLE ENROLE.BULK_DATA_SERVICE
(
	ID BIGINT NOT NULL,
	STARTTIME TIMESTAMP,
	ENDTIME TIMESTAMP,
	MIMETYPE VARCHAR(50),
	NAME VARCHAR(50),
	DATA BLOB(50M),
	FILESIZE INTEGER,
	CONSTRAINT BULK_DATA_SRC_PK PRIMARY KEY(ID)
)
IN ENROLE_DATA INDEX IN ENROLE_INDEXES;

CREATE TABLE ENROLE.BULK_DATA_STORE
(
	ID BIGINT NOT NULL,
	SERVICEID BIGINT NOT NULL,
	XML BLOB(1M),
	CONSTRAINT BULK_DATA_STORE_FK FOREIGN KEY (SERVICEID)
	REFERENCES BULK_DATA_SERVICE (ID) ON DELETE CASCADE,
	CONSTRAINT BULK_DATA_STORE_PK PRIMARY KEY(ID)
)
IN ENROLE_DATA INDEX IN ENROLE_INDEXES;

CREATE INDEX BDS_SID ON ENROLE.BULK_DATA_STORE (SERVICEID DESC);

CREATE TABLE ENROLE.BULK_DATA_INDEX
(
	ID BIGINT NOT NULL,
	STOREID BIGINT NOT NULL,
	DATAOBJECTID VARCHAR(10),
	CONSTRAINT BULK_DATA_INDEX_FK FOREIGN KEY (STOREID)
	REFERENCES BULK_DATA_STORE (ID) ON DELETE CASCADE,
	CONSTRAINT BULK_DATA_INDEX_PK PRIMARY KEY(ID)
)
IN ENROLE_DATA INDEX IN ENROLE_INDEXES;

CREATE INDEX BDI_SID ON ENROLE.BULK_DATA_INDEX (STOREID DESC);
CREATE INDEX BDI_DOID ON ENROLE.BULK_DATA_INDEX (DATAOBJECTID DESC);

create table enrole.MIGRATION_STATUS (
	ID BIGINT NOT NULL,
	processCount INTEGER,
	processStatus VARCHAR(50),
	CONSTRAINT MIG_STATUS_PK PRIMARY KEY(ID)
) IN ENROLE_DATA INDEX IN ENROLE_INDEXES;

COMMIT;

CREATE VIEW enrole.ROOTPROCESSVIEW (ID, TYPE, REQUESTER) AS
(
	(SELECT ID, TYPE, REQUESTER
	FROM enrole.PROCESS
	WHERE  PROCESS.ROOT_PROCESS_ID  = 0
	OR PROCESS.ROOT_PROCESS_ID  = PROCESS.ID
	AND PROCESS.TYPE IN ('OP','AA','AC','UA','UC','UD','US','UR','UO','SR','OA','OC','AD',
						'AS','AR','AP','LO','AO','LS','LR','LP','MS','MR','MD','DA','DC',
						'DD','PA','PC','PD','SA','SC','SD','PS','EN','RC','PE','LC','CP','EP')
	)
	UNION
	(
		SELECT ID, 'AA', REQUESTER
		FROM enrole.PROCESS
		WHERE  PROCESS.ROOT_PROCESS_ID  = 0
		OR PROCESS.ROOT_PROCESS_ID  = PROCESS.ID
		AND PROCESS.TYPE IN ('OA')
	)

	UNION
	(
		SELECT ID, 'AC', REQUESTER
		FROM enrole.PROCESS
		WHERE  PROCESS.ROOT_PROCESS_ID  = 0
		OR PROCESS.ROOT_PROCESS_ID  = PROCESS.ID
		AND PROCESS.TYPE IN ('OC')
	)
);

COMMIT;

CREATE VIEW enrole.SUBPROCESSVIEW (ROOT_PROCESS_ID, SUBMITTED,COMPLETED, SUBJECT_PROFILE, SUBJECT_SERVICE, SUBJECT,
	RESULT_SUMMARY, TYPE, REQUESTER)AS
(
	SELECT ROOT_PROCESS_ID, SUBMITTED,
		COMPLETED, SUBJECT_PROFILE, SUBJECT_SERVICE, SUBJECT,
		RESULT_SUMMARY, TYPE, REQUESTER
	FROM enrole.PROCESS
	WHERE PROCESS.TYPE IN ('OA','OC', 'AD', 'AS', 'AR', 'AP')
);

COMMIT;

CREATE VIEW enrole.PENDING_APPROVAL
(PROCESSID, RESULT_SUMMARY)
AS
	(
		(
			SELECT PROCESS.ID, ACTIVITY.RESULT_SUMMARY
			FROM enrole.PROCESS, enrole.ACTIVITY, enrole.WORKITEM
			WHERE
				WORKITEM.PROCESS_ID = PROCESS.ID AND
				WORKITEM.ACTIVITY_ID = ACTIVITY.ID AND
				WORKITEM.LOCK_OWNER IS NULL
		)
		UNION
		(
			SELECT PROCESS.ID, 'LK'
			FROM enrole.PROCESS, enrole.ACTIVITY, enrole.WORKITEM
			WHERE
				WORKITEM.PROCESS_ID = PROCESS.ID AND
				WORKITEM.ACTIVITY_ID = ACTIVITY.ID AND
				WORKITEM.LOCK_OWNER IS NOT NULL
		)
);

COMMIT;

CREATE TABLE SUMMARY_ORDER (
    RESULT_SUMMARY VARCHAR(2) NOT NULL,
    RESULT_SEVERITY SMALLINT NOT NULL UNIQUE,
    CONSTRAINT Uni_ResultSummary PRIMARY KEY(RESULT_SUMMARY),
    CONSTRAINT Range_Value CHECK (RESULT_SEVERITY >= 0 AND RESULT_SEVERITY <= 100)
);

COMMIT;

INSERT INTO SUMMARY_ORDER(RESULT_SUMMARY, RESULT_SEVERITY) VALUES ('SF', 100);
INSERT INTO SUMMARY_ORDER(RESULT_SUMMARY, RESULT_SEVERITY) VALUES ('SW', 99);
INSERT INTO SUMMARY_ORDER(RESULT_SUMMARY, RESULT_SEVERITY) VALUES ('ST', 98);
INSERT INTO SUMMARY_ORDER(RESULT_SUMMARY, RESULT_SEVERITY) VALUES ('AR', 97);
INSERT INTO SUMMARY_ORDER(RESULT_SUMMARY, RESULT_SEVERITY) VALUES ('PF', 96);
INSERT INTO SUMMARY_ORDER(RESULT_SUMMARY, RESULT_SEVERITY) VALUES ('SK', 95);
INSERT INTO SUMMARY_ORDER(RESULT_SUMMARY, RESULT_SEVERITY) VALUES ('ES', 94);
INSERT INTO SUMMARY_ORDER(RESULT_SUMMARY, RESULT_SEVERITY) VALUES ('AA', 93);
INSERT INTO SUMMARY_ORDER(RESULT_SUMMARY, RESULT_SEVERITY) VALUES ('RS', 92);
INSERT INTO SUMMARY_ORDER(RESULT_SUMMARY, RESULT_SEVERITY) VALUES ('PE', 1);
INSERT INTO SUMMARY_ORDER(RESULT_SUMMARY, RESULT_SEVERITY) VALUES ('SS', 0);

COMMIT;